#
# spec file for package mmtf-cpp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mmtf-cpp
Version:        1.1.0
Release:        1.8
Summary:        The pure C++ implementation of the MMTF API, decoder and encoder
License:        MIT
Group:          Productivity/Scientific/Chemistry
URL:            https://github.com/rcsb/mmtf-cpp
Source0:        %{name}-%{version}.tar
# PATCH-FIX-OPENSUSE fix_catch2_not_found.patch gh#rcsb/mmtf-cpp#39 andythe_great@pm.me -- Fix issue catch.hpp not found.
Patch0:         fix_catch2_not_found.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  msgpack-cxx-devel
BuildRequires:  pkgconfig(catch2) < 3
BuildArch:      noarch

%description
Macromolecular transmission format documentation, including README, license and HTML docs.

%package  devel
Summary:        Development files of %{name}
Group:          Development/Libraries/C and C++
Requires:       msgpack-cxx-devel

%description devel
This package contains libraries and header files for developing
applications that use %{name}.

%prep
%autosetup -p1

%build
%cmake -DBUILD_TESTS:BOOL=ON \
       -Dmmtf_build_local:BOOL=ON

%cmake_build
cd ../docs
doxygen

%install
%cmake_install
# Install doc files manually so we can run fdupes on them
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -pr ./docs/html %{buildroot}%{_docdir}/%{name}/
%fdupes %{buildroot}%{_docdir}/%{name}/html/

%check
%ctest

%files devel
%license LICENSE
%doc README.md
%doc %{_docdir}/%{name}/
%{_includedir}/mmtf/
%{_includedir}/*.hpp

%changelog
* Sat Oct 15 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.1.0:
  * New mapDecoderFrom.. functions to decode only part of an MMTF
    file
  * Support for extra fields in MMTF files according to the latest
    MMTF specification.
  * Support for binary strategy 16 (Run-length encoded 8-bit
    array), bondResonanceList field and optional
    groupType.bondAtomList & groupType.bondOrderList according to
    the proposed version 1.1 of the MMTF specification.
  * New methods to find polymer chains and HETATM following
    discussions in rcsb/mmtf#28.
  * Altered submodule locations rcsb/mmtf-cpp#37 from the base
    directory to the new submodules directory.
- Install documentation to _docdir manually, and run fdupes on
  the doc dir.
- Depend on Catch2 < 3 for tests; not compatible with Catch2 >= 3.
- Switch "recompress" service to disabled (instead of buildtime)
  as it is not really needed at buildtime.
* Sat Sep  3 2022 Jan Engelhardt <jengelh@inai.de>
- msgpack has split into c and cxx variants,
  update BuildRequires accordingly.
* Wed May 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Add msgpack dependency to devel package
- Exclude msgpack and Catch2 submodules from source package
- Do not build unused examples
- Strip unneeded ninjs dependency
* Fri Feb  5 2021 andy great <andythe_great@pm.me>
- Enable test. Add _service file to download submodule required for
  testing.
- Add fix_catch2_not_found.patch to fix catch.hpp not found.
* Tue May  5 2020 andy great <andythe_great@pm.me>
- Remove -s flag from fdupes.
* Thu Mar 19 2020 andy great <andythe_great@pm.me>
- Use cmake macros.
* Tue Mar  3 2020 andy great <andythe_great@pm.me>
- Initial package release.
